@@ -13,6 +13,7 @@
 from dataclasses import dataclass
 import typing_extensions
 import urllib3
+from snaptrade_client.request_before_hook import request_before_hook
 import json
 from urllib3._collections import HTTPHeaderDict
 
@@ -31,9 +32,23 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
+from snaptrade_client.model.exchange import Exchange as ExchangeSchema
+from snaptrade_client.model.option_strategy import OptionStrategy as OptionStrategySchema
 from snaptrade_client.model.strategy_order_record import StrategyOrderRecord as StrategyOrderRecordSchema
+from snaptrade_client.model.security_type import SecurityType as SecurityTypeSchema
+from snaptrade_client.model.option_strategy_legs import OptionStrategyLegs as OptionStrategyLegsSchema
+from snaptrade_client.model.currency import Currency as CurrencySchema
+from snaptrade_client.model.price import Price as PriceSchema
+from snaptrade_client.model.universal_symbol import UniversalSymbol as UniversalSymbolSchema
 
+from snaptrade_client.type.option_strategy_legs import OptionStrategyLegs
+from snaptrade_client.type.security_type import SecurityType
+from snaptrade_client.type.exchange import Exchange
 from snaptrade_client.type.strategy_order_record import StrategyOrderRecord
+from snaptrade_client.type.currency import Currency
+from snaptrade_client.type.universal_symbol import UniversalSymbol
+from snaptrade_client.type.option_strategy import OptionStrategy
+from snaptrade_client.type.price import Price
 
 from . import path
 
@@ -175,7 +190,10 @@ class SchemaForRequestBodyApplicationJson(
                 @schemas.classproperty
                 def GTC(cls):
                     return cls("GTC")
-            price = schemas.NumberSchema
+        
+            @staticmethod
+            def price() -> typing.Type['Price']:
+                return Price
             __annotations__ = {
                 "order_type": order_type,
                 "time_in_force": time_in_force,
@@ -183,7 +201,7 @@ class SchemaForRequestBodyApplicationJson(
             }
     
     time_in_force: MetaOapg.properties.time_in_force
-    price: MetaOapg.properties.price
+    price: 'Price'
     order_type: MetaOapg.properties.order_type
     
     @typing.overload
@@ -193,7 +211,7 @@ class SchemaForRequestBodyApplicationJson(
     def __getitem__(self, name: typing_extensions.Literal["time_in_force"]) -> MetaOapg.properties.time_in_force: ...
     
     @typing.overload
-    def __getitem__(self, name: typing_extensions.Literal["price"]) -> MetaOapg.properties.price: ...
+    def __getitem__(self, name: typing_extensions.Literal["price"]) -> 'Price': ...
     
     @typing.overload
     def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
@@ -210,7 +228,7 @@ class SchemaForRequestBodyApplicationJson(
     def get_item_oapg(self, name: typing_extensions.Literal["time_in_force"]) -> MetaOapg.properties.time_in_force: ...
     
     @typing.overload
-    def get_item_oapg(self, name: typing_extensions.Literal["price"]) -> MetaOapg.properties.price: ...
+    def get_item_oapg(self, name: typing_extensions.Literal["price"]) -> 'Price': ...
     
     @typing.overload
     def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
@@ -223,7 +241,7 @@ class SchemaForRequestBodyApplicationJson(
         cls,
         *args: typing.Union[dict, frozendict.frozendict, ],
         time_in_force: typing.Union[MetaOapg.properties.time_in_force, str, ],
-        price: typing.Union[MetaOapg.properties.price, decimal.Decimal, int, float, ],
+        price: 'Price',
         order_type: typing.Union[MetaOapg.properties.order_type, str, ],
         _configuration: typing.Optional[schemas.Configuration] = None,
         **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
@@ -304,7 +322,7 @@ class BaseApi(api_client.Api):
         body: typing.Optional[typing.Any] = None,
         order_type: typing.Optional[str] = None,
         time_in_force: typing.Optional[str] = None,
-        price: typing.Optional[typing.Union[int, float]] = None,
+        price: typing.Optional[Price] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
         account_id: typing.Optional[str] = None,
@@ -393,21 +411,31 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
     
         if body is schemas.unset:
             raise exceptions.ApiValueError(
                 'The required body parameter has an invalid value of: unset. Set a valid value instead')
         _fields = None
         _body = None
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            body=body,
+            auth_settings=_auth,
+            headers=_headers,
+        )
         serialized_data = request_body_typing_any.serialize(body, content_type)
-        _headers.add('Content-Type', content_type)
         if 'fields' in serialized_data:
             _fields = serialized_data['fields']
         elif 'body' in serialized_data:
-            _body = serialized_data['body']    
+            _body = serialized_data['body']
+    
         response = await self.api_client.async_call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             fields=_fields,
             serialized_body=_body,
@@ -416,8 +444,16 @@ class BaseApi(api_client.Api):
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
         )
-        
+    
         if stream:
+            if not 200 <= response.http_response.status <= 299:
+                body = (await response.http_response.content.read()).decode("utf-8")
+                raise exceptions.ApiStreamingException(
+                    status=response.http_response.status,
+                    reason=response.http_response.reason,
+                    body=body,
+                )
+    
             async def stream_iterator():
                 """
                 iterates over response.http_response.content and closes connection once iteration has finished
@@ -462,6 +498,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
     def _place_option_strategy_oapg(
         self,
         body: typing.Any = None,
@@ -519,21 +556,31 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
     
         if body is schemas.unset:
             raise exceptions.ApiValueError(
                 'The required body parameter has an invalid value of: unset. Set a valid value instead')
         _fields = None
         _body = None
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            body=body,
+            auth_settings=_auth,
+            headers=_headers,
+        )
         serialized_data = request_body_typing_any.serialize(body, content_type)
-        _headers.add('Content-Type', content_type)
         if 'fields' in serialized_data:
             _fields = serialized_data['fields']
         elif 'body' in serialized_data:
-            _body = serialized_data['body']    
+            _body = serialized_data['body']
+    
         response = self.api_client.call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             fields=_fields,
             serialized_body=_body,
@@ -566,6 +613,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
 class PlaceOptionStrategy(BaseApi):
     # this class is used by api classes that refer to endpoints with operationId fn names
 
@@ -574,7 +622,7 @@ class PlaceOptionStrategy(BaseApi):
         body: typing.Optional[typing.Any] = None,
         order_type: typing.Optional[str] = None,
         time_in_force: typing.Optional[str] = None,
-        price: typing.Optional[typing.Union[int, float]] = None,
+        price: typing.Optional[Price] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
         account_id: typing.Optional[str] = None,
@@ -609,7 +657,7 @@ class PlaceOptionStrategy(BaseApi):
         body: typing.Optional[typing.Any] = None,
         order_type: typing.Optional[str] = None,
         time_in_force: typing.Optional[str] = None,
-        price: typing.Optional[typing.Union[int, float]] = None,
+        price: typing.Optional[Price] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
         account_id: typing.Optional[str] = None,
@@ -646,7 +694,7 @@ class ApiForpost(BaseApi):
         body: typing.Optional[typing.Any] = None,
         order_type: typing.Optional[str] = None,
         time_in_force: typing.Optional[str] = None,
-        price: typing.Optional[typing.Union[int, float]] = None,
+        price: typing.Optional[Price] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
         account_id: typing.Optional[str] = None,
@@ -681,7 +729,7 @@ class ApiForpost(BaseApi):
         body: typing.Optional[typing.Any] = None,
         order_type: typing.Optional[str] = None,
         time_in_force: typing.Optional[str] = None,
-        price: typing.Optional[typing.Union[int, float]] = None,
+        price: typing.Optional[Price] = None,
         user_id: typing.Optional[str] = None,
         user_secret: typing.Optional[str] = None,
         account_id: typing.Optional[str] = None,
