@@ -13,6 +13,7 @@
 from dataclasses import dataclass
 import typing_extensions
 import urllib3
+from snaptrade_client.request_before_hook import request_before_hook
 import json
 from urllib3._collections import HTTPHeaderDict
 
@@ -31,10 +32,16 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
+from snaptrade_client.model.exchange import Exchange as ExchangeSchema
 from snaptrade_client.model.symbol_query import SymbolQuery as SymbolQuerySchema
+from snaptrade_client.model.security_type import SecurityType as SecurityTypeSchema
+from snaptrade_client.model.currency import Currency as CurrencySchema
 from snaptrade_client.model.universal_symbol import UniversalSymbol as UniversalSymbolSchema
 
+from snaptrade_client.type.security_type import SecurityType
 from snaptrade_client.type.symbol_query import SymbolQuery
+from snaptrade_client.type.exchange import Exchange
+from snaptrade_client.type.currency import Currency
 from snaptrade_client.type.universal_symbol import UniversalSymbol
 
 from . import path
@@ -126,8 +133,8 @@ class SchemaFor200ResponseBody(
     class MetaOapg:
         
         @staticmethod
-        def items() -> typing.Type['UniversalSymbol']:
-            return UniversalSymbol
+        def items() -> typing.Type['UniversalSymbolSchema']:
+            return UniversalSymbolSchema
 
     def __new__(
         cls,
@@ -232,7 +239,7 @@ class BaseApi(api_client.Api):
         AsyncGeneratorResponse,
     ]:
         """
-        Search for symbols that are supported by a brokerage account using a substring
+        Search for symbols available in an account
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -273,19 +280,29 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
     
         _fields = None
         _body = None
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            body=body,
+            auth_settings=_auth,
+            headers=_headers,
+        )
         if body is not schemas.unset:
             serialized_data = request_body_symbol_query.serialize(body, content_type)
-            _headers.add('Content-Type', content_type)
             if 'fields' in serialized_data:
                 _fields = serialized_data['fields']
             elif 'body' in serialized_data:
-                _body = serialized_data['body']    
+                _body = serialized_data['body']
+    
         response = await self.api_client.async_call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             fields=_fields,
             serialized_body=_body,
@@ -294,8 +311,16 @@ class BaseApi(api_client.Api):
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
         )
-        
+    
         if stream:
+            if not 200 <= response.http_response.status <= 299:
+                body = (await response.http_response.content.read()).decode("utf-8")
+                raise exceptions.ApiStreamingException(
+                    status=response.http_response.status,
+                    reason=response.http_response.reason,
+                    body=body,
+                )
+    
             async def stream_iterator():
                 """
                 iterates over response.http_response.content and closes connection once iteration has finished
@@ -345,6 +370,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
     def _symbol_search_user_account_oapg(
         self,
         body: typing.Any = None,
@@ -361,7 +387,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        Search for symbols that are supported by a brokerage account using a substring
+        Search for symbols available in an account
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -402,19 +428,29 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
     
         _fields = None
         _body = None
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            body=body,
+            auth_settings=_auth,
+            headers=_headers,
+        )
         if body is not schemas.unset:
             serialized_data = request_body_symbol_query.serialize(body, content_type)
-            _headers.add('Content-Type', content_type)
             if 'fields' in serialized_data:
                 _fields = serialized_data['fields']
             elif 'body' in serialized_data:
-                _body = serialized_data['body']    
+                _body = serialized_data['body']
+    
         response = self.api_client.call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             fields=_fields,
             serialized_body=_body,
@@ -452,6 +488,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
 class SymbolSearchUserAccount(BaseApi):
     # this class is used by api classes that refer to endpoints with operationId fn names
 
