@@ -32,9 +32,27 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
+from snaptrade_client.model.exchange import Exchange as ExchangeSchema
 from snaptrade_client.model.universal_activity import UniversalActivity as UniversalActivitySchema
+from snaptrade_client.model.symbol import Symbol as SymbolSchema
+from snaptrade_client.model.account_simple import AccountSimple as AccountSimpleSchema
+from snaptrade_client.model.options_symbol import OptionsSymbol as OptionsSymbolSchema
+from snaptrade_client.model.account_sync_status import AccountSyncStatus as AccountSyncStatusSchema
+from snaptrade_client.model.security_type import SecurityType as SecurityTypeSchema
+from snaptrade_client.model.currency import Currency as CurrencySchema
+from snaptrade_client.model.underlying_symbol import UnderlyingSymbol as UnderlyingSymbolSchema
+from snaptrade_client.model.us_exchange import USExchange as USExchangeSchema
 
+from snaptrade_client.type.options_symbol import OptionsSymbol
+from snaptrade_client.type.security_type import SecurityType
+from snaptrade_client.type.exchange import Exchange
+from snaptrade_client.type.account_simple import AccountSimple
 from snaptrade_client.type.universal_activity import UniversalActivity
+from snaptrade_client.type.us_exchange import USExchange
+from snaptrade_client.type.underlying_symbol import UnderlyingSymbol
+from snaptrade_client.type.currency import Currency
+from snaptrade_client.type.account_sync_status import AccountSyncStatus
+from snaptrade_client.type.symbol import Symbol
 
 from . import path
 
