@@ -32,8 +32,14 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
+from snaptrade_client.model.exchange import Exchange as ExchangeSchema
+from snaptrade_client.model.security_type import SecurityType as SecurityTypeSchema
+from snaptrade_client.model.currency import Currency as CurrencySchema
 from snaptrade_client.model.universal_symbol import UniversalSymbol as UniversalSymbolSchema
 
+from snaptrade_client.type.security_type import SecurityType
+from snaptrade_client.type.exchange import Exchange
+from snaptrade_client.type.currency import Currency
 from snaptrade_client.type.universal_symbol import UniversalSymbol
 
 from . import path
@@ -65,11 +71,11 @@ request_query_symbol_id = api_client.QueryParameter(
     explode=True,
 )
 # Path params
-TickerSchema = schemas.UUIDSchema
+TickerSchema = schemas.StrSchema
 RequestRequiredPathParams = typing_extensions.TypedDict(
     'RequestRequiredPathParams',
     {
-        'ticker': typing.Union[TickerSchema, str, uuid.UUID, ],
+        'ticker': typing.Union[TickerSchema, str, ],
     }
 )
 RequestOptionalPathParams = typing_extensions.TypedDict(
