@@ -13,6 +13,7 @@
 from dataclasses import dataclass
 import typing_extensions
 import urllib3
+from snaptrade_client.request_before_hook import request_before_hook
 import json
 from urllib3._collections import HTTPHeaderDict
 
@@ -31,10 +32,42 @@ import frozendict  # noqa: F401
 
 from snaptrade_client import schemas  # noqa: F401
 
+from snaptrade_client.model.exchange import Exchange as ExchangeSchema
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse as Model400FailedRequestResponseSchema
+from snaptrade_client.model.stop_price import StopPrice as StopPriceSchema
+from snaptrade_client.model.time_in_force import TimeInForce as TimeInForceSchema
+from snaptrade_client.model.security_type import SecurityType as SecurityTypeSchema
+from snaptrade_client.model.order_type import OrderType as OrderTypeSchema
+from snaptrade_client.model.price import Price as PriceSchema
+from snaptrade_client.model.action import Action as ActionSchema
+from snaptrade_client.model.options_symbol import OptionsSymbol as OptionsSymbolSchema
+from snaptrade_client.model.filled_units import FilledUnits as FilledUnitsSchema
+from snaptrade_client.model.cancelled_units import CancelledUnits as CancelledUnitsSchema
 from snaptrade_client.model.account_order_record import AccountOrderRecord as AccountOrderRecordSchema
+from snaptrade_client.model.currency import Currency as CurrencySchema
+from snaptrade_client.model.underlying_symbol import UnderlyingSymbol as UnderlyingSymbolSchema
+from snaptrade_client.model.us_exchange import USExchange as USExchangeSchema
+from snaptrade_client.model.universal_symbol import UniversalSymbol as UniversalSymbolSchema
+from snaptrade_client.model.open_units import OpenUnits as OpenUnitsSchema
+from snaptrade_client.model.account_order_record_status import AccountOrderRecordStatus as AccountOrderRecordStatusSchema
 
+from snaptrade_client.type.account_order_record_status import AccountOrderRecordStatus
+from snaptrade_client.type.time_in_force import TimeInForce
+from snaptrade_client.type.security_type import SecurityType
+from snaptrade_client.type.filled_units import FilledUnits
 from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
+from snaptrade_client.type.stop_price import StopPrice
+from snaptrade_client.type.currency import Currency
+from snaptrade_client.type.price import Price
+from snaptrade_client.type.order_type import OrderType
+from snaptrade_client.type.action import Action
+from snaptrade_client.type.cancelled_units import CancelledUnits
+from snaptrade_client.type.options_symbol import OptionsSymbol
+from snaptrade_client.type.exchange import Exchange
+from snaptrade_client.type.us_exchange import USExchange
+from snaptrade_client.type.underlying_symbol import UnderlyingSymbol
+from snaptrade_client.type.open_units import OpenUnits
+from snaptrade_client.type.universal_symbol import UniversalSymbol
 from snaptrade_client.type.account_order_record import AccountOrderRecord
 
 from . import path
@@ -252,17 +285,33 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            auth_settings=_auth,
+            headers=_headers,
+        )
     
         response = await self.api_client.async_call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
         )
-        
+    
         if stream:
+            if not 200 <= response.http_response.status <= 299:
+                body = (await response.http_response.content.read()).decode("utf-8")
+                raise exceptions.ApiStreamingException(
+                    status=response.http_response.status,
+                    reason=response.http_response.reason,
+                    body=body,
+                )
+    
             async def stream_iterator():
                 """
                 iterates over response.http_response.content and closes connection once iteration has finished
@@ -307,6 +356,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
     def _place_order_oapg(
         self,
         query_params: typing.Optional[dict] = {},
@@ -361,10 +411,18 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            auth_settings=_auth,
+            headers=_headers,
+        )
     
         response = self.api_client.call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
@@ -394,6 +452,7 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
 class PlaceOrder(BaseApi):
     # this class is used by api classes that refer to endpoints with operationId fn names
 
